@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2022 The pyXem developers
+# Copyright 2016-2023 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -72,7 +72,7 @@ class TestComputeAndAsLazy2D:
 class TestGetPower:
     @pytest.fixture
     def flat_pattern(self):
-        pd = Correlation2D(data=np.ones(shape=(2, 2, 5, 5)))
+        pd = Correlation2D(data=np.ones(shape=(2, 2, 25, 25)))
         pd.axes_manager.signal_axes[0].scale = 0.5
         pd.axes_manager.signal_axes[0].name = "theta"
         pd.axes_manager.signal_axes[1].scale = 2
@@ -97,6 +97,28 @@ class TestGetPower:
         assert isinstance(flat_pattern, Power2D)
         assert power is None
 
+    @pytest.mark.parametrize("method", ["max", "first", "average"])
+    def test_symmetry_stem_max_first(self, flat_pattern, method):
+        sym_coeff = flat_pattern.get_symmetry_coefficient(method=method)
+        np.testing.assert_array_almost_equal(sym_coeff.data, sym_coeff.data[0, 0, 0, 0])
+
+    def test_symmetry_stem_max(self, flat_pattern):
+        sym_coeff = flat_pattern.get_symmetry_coefficient(method="max")
+        np.testing.assert_array_almost_equal(sym_coeff.data, sym_coeff.data[0, 0, 0, 0])
+
+    def test_symmetry_stem_average(self, flat_pattern):
+        sym_coeff = flat_pattern.get_symmetry_coefficient(
+            method="average", angular_range=0.01, normalize=True
+        )
+        np.testing.assert_array_almost_equal(sym_coeff.data, sym_coeff.data[0, 0, 0, 0])
+
+    def test_symmetry_stem_lazy(self, flat_pattern):
+        flat_pattern = flat_pattern.as_lazy()
+        sym_coeff = flat_pattern.get_symmetry_coefficient(
+            method="average", angular_range=0.01, normalize=True
+        )
+        assert isinstance(sym_coeff.data, da.Array)
+
 
 class TestDecomposition:
     def test_decomposition_is_performed(self, diffraction_pattern):
