@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2022 The pyXem developers
+# Copyright 2016-2023 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -47,10 +47,6 @@ def test_load_function_core(class_to_test, meta_string):
     """
     to_save = class_to_test(np.zeros((2, 2, 2, 2)))
     to_save.metadata.Signal.tracker = meta_string
-    if class_to_test is DiffractionVectors:
-        to_save.axes_manager.set_signal_dimension(0)
-    if class_to_test is DiffractionVectors2D:
-        to_save.axes_manager.set_signal_dimension(2)
     to_save.save("tempfile_for_load_and_save.hspy", overwrite=True)
     from_save = hs.load("tempfile_for_load_and_save.hspy")
     assert isinstance(from_save, class_to_test)
