@@ -123,10 +123,11 @@ def separate_watershed(
     """
 
     # Create a mask from the input VDF image.
-    if threshold:
+    if not isinstance(threshold, bool):
+        mask = vdf_temp > np.max(vdf_temp) * threshold
+    elif threshold:
         th = threshold_li(vdf_temp)
-        mask = np.zeros_like(vdf_temp)
-        mask[vdf_temp > th] = True
+        mask = vdf_temp > th
     else:
         mask = vdf_temp.astype("bool")
 
